@@ -120,6 +120,8 @@ _SETTINGS = {
     },
     'PROCESSOR_BACKEND_CALLABLE': None,
     'ROLE_RELATION': 'saas.Role',
+    'ROLE_SERIALIZER': 'saas.api.serializers.RoleSerializer',
+    'USER_SERIALIZER': 'saas.api.serializers_overrides.UserSerializer',
     'SEARCH_FIELDS_PARAM': 'q_f',
     'TERMS_OF_USE': 'terms-of-use',
 }
@@ -157,6 +159,8 @@ PROCESSOR_ID = PROCESSOR.get('INSTANCE_PK', 1)
 PROCESSOR_HOOK_URL = PROCESSOR.get('WEBHOOK_URL', 'stripe/postevent')
 PROCESSOR_HOOK_SECRET = PROCESSOR.get('WEBHOOK_SECRET')
 ROLE_RELATION = _SETTINGS.get('ROLE_RELATION')
+ROLE_SERIALIZER = _SETTINGS.get('ROLE_SERIALIZER')
+USER_SERIALIZER = _SETTINGS.get('USER_SERIALIZER')
 SEARCH_FIELDS_PARAM = _SETTINGS.get('SEARCH_FIELDS_PARAM')
 TERMS_OF_USE = _SETTINGS.get('TERMS_OF_USE')
 
