@@ -1,75 +1,10 @@
-// Copyright (c) 2020, DjaoDjin inc.
+// Copyright (c) 2021, DjaoDjin inc.
 // All rights reserved.
 // BSD 2-Clause license
 
-/*global Vue jQuery moment interpolate gettext showMessages showErrorMessages Stripe updateBarChart updateChart getUrlParameter $ */
+/*global Vue jQuery moment showMessages showErrorMessages Stripe updateBarChart updateChart getUrlParameter $ */
 
 
-Vue.filter('formatDate', function(value, format) {
-  if (value) {
-    if(!format){
-//        format = 'MM/DD/YYYY hh:mm'
-        format = "MMM D, YYYY";
-    }
-    if(!(value instanceof Date)){
-        value = String(value);
-    }
-    return moment(value).format(format)
-  }
-});
-
-
-Vue.filter("monthHeading", function(d) {
-    // shift each period by 1 month unless this is
-    // current month and not a first day of the month
-    if( typeof d === 'string' ) {
-        d = moment(d);
-    }
-    if(d.date() !== 1 || d.hour() !== 0
-       || d.minute() !== 0 || d.second() !== 0 ) {
-        return d.format("MMM'YY*");
-    }
-    return d.clone().subtract(1, 'months').format("MMM'YY");
-});
-
-
-Vue.filter('currencyToSymbol', function(currency) {
-    if( currency === "usd" || currency === "cad" ) { return "$"; }
-    else if( currency === "eur" ) { return "\u20ac"; }
-    return currency;
-});
-
-
-Vue.filter('humanizeCell', function(cell, unit, scale) {
-    var currencyFilter = Vue.filter('currency');
-    var currencyToSymbolFilter = Vue.filter('currencyToSymbol');
-    scale = scale || 1;
-    var value = cell * scale;
-    var symbol = '';
-    var precision = 0;
-    if(unit) {
-        symbol = currencyToSymbolFilter(unit);
-        precision = 2;
-    }
-    return currencyFilter(value, symbol, precision);
-});
-
-
-Vue.filter('relativeDate', function(at_time) {
-    var cutOff = moment();
-    if( this.ends_at ) {
-        cutOff = moment(this.ends_at, DATE_FORMAT);
-    }
-    var dateTime = moment(at_time);
-    if( dateTime <= cutOff ) {
-        return interpolate(gettext('%s ago'),
-            [moment.duration(cutOff.diff(dateTime)).humanize()]);
-    } else {
-        return interpolate(gettext('%s left'),
-            [moment.duration(dateTime.diff(cutOff)).humanize()]);
-    }
-});
-
 var countries = {
     "AF": "Afghanistan",
     "AX": "Åland Islands",
@@ -404,8 +339,6 @@ var regions = {
     }
 }
 
-var DATE_FORMAT = 'MMM DD, YYYY';
-
 
 var timezoneMixin = {
     data: function(){
@@ -425,6 +358,20 @@ var timezoneMixin = {
                 });
             });
         },
+
+        // Used to be filters but Vue3 will not allow it.
+        monthHeading: function(datetime) {
+            // shift each period by 1 month unless this is
+            // current month and not a first day of the month
+            if( typeof datetime === 'string' ) {
+                datetime = moment(datetime);
+            }
+            if(datetime.date() !== 1 || datetime.hour() !== 0
+               || datetime.minute() !== 0 || datetime.second() !== 0 ) {
+                return datetime.format("MMM'YY*");
+            }
+            return datetime.clone().subtract(1, 'months').format("MMM'YY");
+        },
     },
 }
 
@@ -439,6 +386,7 @@ var cardMixin = {
             api_profile_url: this.$urls.organization.api_base,
             processor_pub_key: null,
             stripe_intent_secret: null,
+            stripe_account: null,
             stripe: null,
             cardNumber: '',
             cardCvc: '',
@@ -471,6 +419,19 @@ var cardMixin = {
                 'country',
                 'region',
             ],
+            labels: {
+                cardNumberLabel: (this.$labels && this.$labels.cardNumberLabel) || "Card Number",
+                securityCodeLabel: (this.$labels && this.$labels.securityCodeLabel) || "Security Code",
+                expirationLabel: (this.$labels && this.$labels.expirationLabel) || "Expiration",
+                cardHolderLabel: (this.$labels && this.$labels.cardHolderLabel) || "Card Holder",
+                streetAddressLabel: (this.$labels && this.$labels.streetAddressLabel) || "Street address",
+                localityLabel: (this.$labels && this.$labels.localityLabel) || "City/Town",
+                regionLabel: (this.$labels && this.$labels.regionLabel) || "State/Province/County",
+                postalCodeLabel: (this.$labels && this.$labels.postalCodeLabel) || "Zip/Postal code",
+                countryLabel: (this.$labels && this.$labels.countryLabel) || "Country",
+                fieldShoundNotBeEmptyError: (this.$labels && this.$labels.fieldShoundNotBeEmptyError) || "This field shouldn't be empty",
+                fieldsCannotBeEmptyError: (this.$labels && this.$labels.fieldsCannotBeEmptyError) || " field(s) cannot be empty."
+            }
         }, this.getCardFormData());
     },
     methods: {
@@ -500,11 +461,11 @@ var cardMixin = {
         deleteCard: function() {
             var vm = this;
             vm.reqDelete(vm.api_card_url,
-            function() {
+            function(resp) {
                 vm.clearCardData();
-                showMessages([gettext(
-                    "Your credit card is no longer on file with us.")],
-                    "success");
+                if( resp.detail ) {
+                    showMessages([resp.detail], "success");
+                }
             });
         },
         inputClass: function(name){
@@ -545,14 +506,23 @@ var cardMixin = {
                 if( resp.exp_date ) {
                     vm.savedCard.exp_date = resp.exp_date;
                 }
-                if( resp.STRIPE_PUB_KEY ) {
-                    vm.processor_pub_key = resp.STRIPE_PUB_KEY;
+                if( resp.processor && resp.processor.STRIPE_PUB_KEY ) {
+                    vm.processor_pub_key = resp.processor.STRIPE_PUB_KEY;
                 }
-                if( resp.STRIPE_INTENT_SECRET ) {
-                    vm.stripe_intent_secret = resp.STRIPE_INTENT_SECRET;
+                if( resp.processor && resp.processor.STRIPE_INTENT_SECRET ) {
+                    vm.stripe_intent_secret = resp.processor.STRIPE_INTENT_SECRET;
+                }
+                if( resp.processor && resp.processor.STRIPE_ACCOUNT ) {
+                    vm.stripe_account = resp.processor.STRIPE_ACCOUNT;
                 }
                 if( vm.processor_pub_key ) {
-                    vm.stripe = Stripe(vm.processor_pub_key);
+                    if( vm.stripe_account ) {
+                        vm.stripe = Stripe(vm.processor_pub_key, {
+                            stripeAccount: vm.stripe_account
+                        });
+                    } else {
+                        vm.stripe = Stripe(vm.processor_pub_key);
+                    }
                     if( vm.stripe_intent_secret ) {
                         var elements = vm.stripe.elements();
                         vm.cardElement = elements.create("card", {
@@ -568,9 +538,7 @@ var cardMixin = {
             // this identifies your website in the createToken call below
             if( vm.stripe_intent_secret ) {
                 if( !vm.stripe ){
-                    showMessages([
-                        gettext("You haven't set a valid Stripe public key")
-                    ], "error");
+                    showErrorMessages("You haven't set a valid Stripe public key");
                     return;
                 }
                 if( vm.stripe_intent_secret.substring(0, 3) === 'pi_' ) {
@@ -690,51 +658,50 @@ var cardMixin = {
                 }
                 if( vm[field] === '') {
                     valid = false;
-                    errors[field] = [gettext("This field shouldn't be empty")];
+                    errors[field] = [vm.labels.fieldShoundNotBeEmptyError];
                 }
             });
             vm.errors = errors;
             if(Object.keys(vm.errors).length > 0){
                 if( vm.errors['cardNumber'] ) {
                     if( errorMessages ) { errorMessages += ", "; }
-                    errorMessages += gettext("Card Number");
+                    errorMessages += vm.labels.cardNumberLabel;
                 }
                 if( vm.errors['cardCvc'] ) {
                     if( errorMessages ) { errorMessages += ", "; }
-                    errorMessages += gettext("Security Code");
+                    errorMessages += vm.labels.securityCodeLabel;
                 }
                 if( vm.errors['cardExpMonth']
                          || vm.errors['cardExpYear'] ) {
                     if( errorMessages ) { errorMessages += ", "; }
-                    errorMessages += gettext("Expiration");
+                    errorMessages += vm.labels.expirationLabel;
                 }
                 if( vm.errors['card_name'] ) {
                     if( errorMessages ) { errorMessages += ", "; }
-                    errorMessages += gettext("Card Holder");
+                    errorMessages +=  vm.labels.cardHolderLabel;
                 }
                 if( vm.errors['card_address_line1'] ) {
                     if( errorMessages ) { errorMessages += ", "; }
-                    errorMessages += gettext("Street address");
+                    errorMessages += vm.labels.streetAddressLabel;
                 }
                 if( vm.errors['card_city'] ) {
                     if( errorMessages ) { errorMessages += ", "; }
-                    errorMessages += gettext("City/Town");
+                    errorMessages += vm.labels.localityLabel;
                 }
                 if( vm.errors['card_address_zip'] ) {
                     if( errorMessages ) { errorMessages += ", "; }
-                    errorMessages += gettext("Zip/Postal code");
+                    errorMessages += vm.labels.regionLabel;
                 }
                 if( vm.errors['country'] ) {
                     if( errorMessages ) { errorMessages += ", "; }
-                    errorMessages += gettext("Country");
+                    errorMessages += vm.labels.countryLabel;
                 }
                 if( vm.errors['region'] ) {
                     if( errorMessages ) { errorMessages += ", "; }
-                    errorMessages += gettext("State/Province/County");
+                    errorMessages += vm.labels.postalCodeLabel;
                 }
                 if( errorMessages ) {
-                    errorMessages = interpolate(
-                      gettext("%s field(s) cannot be empty."), [errorMessages]);
+                    errorMessages = errorMessages + vm.labels.fieldsCannotBeEmptyError;
                 }
                 showErrorMessages(errorMessages);
             }
@@ -760,8 +727,15 @@ var cardMixin = {
         vm.processor_pub_key = vm.$el.getAttribute('data-processor-pub-key');
         vm.stripe_intent_secret = vm.$el.getAttribute(
             'data-stripe-intent-secret');
+        vm.stripe_account =  vm.$el.getAttribute('data-stripe-account');
         if( vm.processor_pub_key ) {
-            vm.stripe = Stripe(vm.processor_pub_key);
+            if( vm.stripe_account ) {
+                vm.stripe = Stripe(vm.processor_pub_key, {
+                    stripeAccount: vm.stripe_account
+                });
+            } else {
+                vm.stripe = Stripe(vm.processor_pub_key);
+            }
             if( vm.stripe_intent_secret ) {
                 var elements = vm.stripe.elements();
                 vm.cardElement = elements.create("card", {
@@ -783,10 +757,8 @@ var roleDetailMixin = {
         },
         sendInvite: function(slug){
             var vm = this;
-            vm.reqPost(vm.url + '/' + slug + '/', {}, function() {
-                showMessages([interpolate(gettext(
-                    "Invite for %s has been sent"), [slug])],
-                    "success");
+            vm.reqPost(vm.url + '/' + slug + '/', {}, function(resp) {
+                showMessages([resp.detail], "success");
             });
         },
     }
@@ -1373,16 +1345,15 @@ Vue.component('coupon-list', {
             this.update(coupon);
         },
         planTitle: function(slug){
-            var title = gettext('No plan');
-            if(this.plans.length > 0){
-                this.plans.forEach(function(e){
-                    if(e.slug === slug){
-                        title = e.title;
-                        return;
+            var vm = this;
+            if( vm.plans.length > 0 ) {
+                for( var idx = 0; idx < vm.plans.length; ++idx ) {
+                    if( vm.plans[idx].slug === slug ) {
+                        return vm.plans[idx].title;
                     }
-                });
+                }
             }
-            return title;
+            return "";
         },
     },
     mounted: function(){
@@ -1553,16 +1524,23 @@ Vue.component('metrics-charts', {
                 }
             });
         },
+        currencyToSymbol: function(currency) {
+            // This is a copy/paste from the definition of `currencyToSymbol`
+            // in `itemListMixin`.
+            if( currency === "usd" || currency === "cad" ) { return "$"; }
+            else if( currency === "eur" ) { return "\u20ac"; }
+            return currency;
+        },
         tabClicked: function(index) {
             var vm = this;
             vm.activeTab = index;
             vm.prepareCurrentTabData();
         },
         tabTitle: function(table){
-            var filter = Vue.filter('currencyToSymbol');
+            var vm = this;
             var unit = '';
             if(table && table.unit){
-                unit = ' (' + filter(table.unit) + ')';
+                unit = ' (' + vm.currencyToSymbol(table.unit) + ')';
             }
             return table.title + unit;
         },
@@ -1571,10 +1549,6 @@ Vue.component('metrics-charts', {
             var base = 'nav-link';
             return (index === vm.activeTab) ? base + " active" : base;
         },
-        humanizeCell: function(value, unit, scale) {
-            var filter = Vue.filter('humanizeCell');
-            return filter(value, unit, scale);
-        },
     },
     computed: {
         currentTable: function(){
@@ -1661,19 +1635,6 @@ Vue.component('lifetimevalue-list', {
             url: this.$urls.provider.api_metrics_lifetimevalue
         }
     },
-    methods: {
-        humanizeCell: function(value, unit, scale) {
-            var vm = this;
-            if( typeof unit == 'undefined' ) {
-                unit = vm.items.unit;
-            }
-            if( typeof scale == 'undefined' ) {
-                scale = vm.items.scale;
-            }
-            var filter = Vue.filter('humanizeCell');
-            return filter(value, unit, scale);
-        },
-    },
     mounted: function(){
         this.get();
     }
@@ -1813,19 +1774,17 @@ Vue.component('import-transaction', {
     methods: {
         addPayment: function(){
             var vm = this;
-            var sel = vm.itemSelected
-            if(!sel.plan){
-                alert(gettext('select a subscription from dropdown'));
-                return;
+            if( vm.itemSelected ) {
+                vm.entry.subscription = (vm.itemSelected.organization.slug
+                    + ':' + vm.itemSelected.plan.slug);
             }
-            vm.entry.subscription = (
-                sel.organization.slug + ':' + sel.plan.slug);
             vm.entry.created_at = moment(vm.entry.created_at).toISOString();
             vm.reqPost(vm.url, vm.entry,
-            function () {
+            function(resp) {
                 vm.clearNewPayment();
-                showMessages([gettext("Transaction imported successfully.")],
-                    "success");
+                if( resp.detail ) {
+                    showMessages([resp.detail], "success");
+                }
             });
         },
         clearNewPayment: function() {
@@ -1874,8 +1833,8 @@ Vue.component('billing-statement', {
         var res = {
             url: this.$urls.organization.api_transactions,
             api_cancel_balance_url: this.$urls.organization.api_cancel_balance_due,
-            last4: gettext("N/A"),
-            exp_date: gettext("N/A"),
+            last4: (this.$labels && this.$labels.notAvailableLabel) || "N/A",
+            exp_date: (this.$labels && this.$labels.notAvailableLabel) || "N/A",
             cardLoaded: false
         }
         return res;
@@ -1932,9 +1891,9 @@ Vue.component('transfers-statement', {
             url: this.$urls.organization.api_transactions,
             api_balance_url: this.$urls.provider.api_bank,
             balanceLoaded: false,
-            last4: gettext("N/A"),
-            bank_name: gettext("N/A"),
-            balance_amount: gettext("N/A"),
+            last4: (this.$labels && this.$labels.notAvailableLabel) || "N/A",
+            bank_name: (this.$labels && this.$labels.notAvailableLabel) || "N/A",
+            balance_amount: (this.$labels && this.$labels.notAvailableLabel) || "N/A",
             balance_unit: '',
         }
     },
@@ -1950,11 +1909,6 @@ Vue.component('transfers-statement', {
                 vm.balanceLoaded = true;
             });
         },
-        humanizeBalance: function() {
-            var vm = this;
-            var filter = Vue.filter('humanizeCell');
-            return filter(vm.balance_amount, vm.balance_unit, 0.01);
-        },
     },
     mounted: function(){
         this.getBalance();
@@ -2022,8 +1976,10 @@ Vue.component('profile-update', {
                 }
             }
             vm.reqPut(vm.url, data,
-            function() {
-                showMessages([gettext("Profile was updated.")], "success");
+            function(resp) {
+                if( resp.detail ) {
+                    showMessages([resp.detail], "success");
+                }
             });
             if(vm.imageSelected){
                 vm.uploadProfilePicture();
@@ -2138,17 +2094,6 @@ Vue.component('balance-list', {
                 }
             });
         },
-        humanizeCell: function(value, unit, scale) {
-            var vm = this;
-            if( typeof unit == 'undefined' ) {
-                unit = vm.items.unit;
-            }
-            if( typeof scale == 'undefined' ) {
-                scale = vm.items.scale;
-            }
-            var filter = Vue.filter('humanizeCell');
-            return filter(value, unit, scale);
-        },
         remove: function(id){
             var vm = this;
             vm.reqDelete(vm.balanceLineUrl + '/' + id, function() {
@@ -2206,9 +2151,10 @@ Vue.component('checkout', {
         redeem: function(){
             var vm = this;
             vm.reqPost(vm.api_redeem_url, {code: vm.coupon},
-            function() {
-                showMessages([gettext("Discount was successfully applied.")],
-                    "success");
+            function(resp) {
+                if( resp.detail ) {
+                    showMessages([resp.detail], "success");
+                }
                 vm.get();
             });
         },
@@ -2260,8 +2206,10 @@ Vue.component('checkout', {
                 data.option = option
             }
             vm.reqPost(vm.api_cart_url, data,
-            function() {
-                showMessages([gettext("User was added.")], "success");
+            function(resp) {
+                if( resp.detail ) {
+                    showMessages([resp.detail], "success");
+                }
                 vm.init = false;
                 vm.$set(vm.plansUser, plan, {
                     fullName: '',
@@ -2480,9 +2428,9 @@ Vue.component('card-update', {
                     if( redirectUrl ) {
                         window.location = redirectUrl;
                     }
-                    showMessages([gettext(
-                        "Your credit card on file was sucessfully updated.")],
-                        "success");
+                    if( resp.detail ) {
+                        showMessages([resp.detail], "success");
+                    }
                 });
             });
         },
@@ -2600,11 +2548,8 @@ Vue.component('plan-update', {
             var vm = this;
             if( vm.url ) {
                 vm.reqPut(vm.url, vm._populateParams(),
-                function() {
-                    showMessages([interpolate(gettext(
-                        "Successfully updated plan titled '%s'."), [
-                            vm.formFields.title])
-                                 ], "success");
+                function(resp) {
+                    showMessages([resp.detail], "success");
                 });
             } else {
                 vm.createPlan();
